@@ -1,21 +1,24 @@
 from enum import Enum
 
 class CautionHourType(Enum):
-    SUAVE = "Suave"
-    INTERMEDIATE = "Intermediate"
-    AGGRESSIVE = "Aggressive"
+    SUAVE = "suave"
+    INTERMEDIATE = "intermediate"
+    AGGRESSIVE = "aggressive"
 
     @staticmethod
     def get_num_value(type_state):
-        values = {
+        if isinstance(type_state, str):
+            tt = type_state.lower()
+        elif isinstance(type_state, CautionHourType):
+            tt = type_state.value
+        else:
+            print(f"type of {type_state} is {type(type_state)}")
+            raise ValueError
+        
+        return VALUES_CONVERSION[tt]
+
+VALUES_CONVERSION = {
             CautionHourType.SUAVE.value: 0.75,
             CautionHourType.INTERMEDIATE.value: 0.5,
             CautionHourType.AGGRESSIVE.value: 0.4
             }
-
-        if isinstance(type_state, str):
-            tt = type_state
-        elif isinstance(type_state, CautionHourType):
-            tt = type_state.value
-
-        return values[tt]
