@@ -1,4 +1,4 @@
-from ...models.chargerstates import CHARGERSTATES
+from ...models.chargecontroller_states import ChargeControllerStates
 from .chargecontrollerbase import ChargeControllerBase
 
 
@@ -6,19 +6,19 @@ class ChargeControllerLite(ChargeControllerBase):
     def __init__(self, hub):
         super().__init__(hub)
 
-    def _get_status_charging(self) -> CHARGERSTATES:
+    def _get_status_charging(self) -> ChargeControllerStates:
         if self._hub.totalhourlyenergy.value >= self._hub.current_peak_dynamic and self._hub.locale.data.free_charge(self._hub.locale.data) is False:
-            ret = CHARGERSTATES.Stop
+            ret = ChargeControllerStates.Stop
         else:
-            ret = CHARGERSTATES.Start
+            ret = ChargeControllerStates.Start
         return ret
 
-    def _get_status_connected(self, charger_state = None) -> CHARGERSTATES:
+    def _get_status_connected(self, charger_state = None) -> ChargeControllerStates:
         if charger_state is not None and self._hub.sensors.carpowersensor.value < 1 and self._is_done(charger_state):
-            ret = CHARGERSTATES.Done
+            ret = ChargeControllerStates.Done
         else:
             if (self._hub.totalhourlyenergy.value < self._hub.current_peak_dynamic) or self._hub.locale.data.free_charge(self._hub.locale.data) is True:
-                ret = CHARGERSTATES.Start
+                ret = ChargeControllerStates.Start
             else:
-                ret = CHARGERSTATES.Stop
+                ret = ChargeControllerStates.Stop
         return ret
